-------------------------------------------------------------------------------
--
-- Copyright (C) 2012-2014
-- ASTRON (Netherlands Institute for Radio Astronomy) <http://www.astron.nl/>
-- P.O.Box 2, 7990 AA Dwingeloo, The Netherlands
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-------------------------------------------------------------------------------

-- Purpose: Provide MM slave register for unb2b_fpga_sens
--

LIBRARY IEEE, common_lib, technology_lib, fpga_sense_lib;
USE IEEE.STD_LOGIC_1164.ALL;
USE IEEE.NUMERIC_STD.ALL;
USE common_lib.common_pkg.ALL;
USE common_lib.common_mem_pkg.ALL;
USE technology_lib.technology_pkg.ALL;


ENTITY unb2b_fpga_sens_reg IS
  GENERIC (
    g_sim             : BOOLEAN;
    g_technology      : NATURAL := c_tech_arria10;
    g_sens_nof_result : NATURAL := 1;
    g_temp_high       : NATURAL := 85
  );
  PORT (
    -- Clocks and reset
    mm_rst     : IN  STD_LOGIC;   -- reset synchronous with mm_clk
    mm_clk     : IN  STD_LOGIC;   -- memory-mapped bus clock
    start      : IN  STD_LOGIC;
    
    -- Memory Mapped Slave in mm_clk domain
    sla_temp_in     : IN  t_mem_mosi;  -- actual ranges defined by c_mm_reg
    sla_temp_out    : OUT t_mem_miso;  -- actual ranges defined by c_mm_reg
    
    sla_voltage_in     : IN  t_mem_mosi;  -- actual ranges defined by c_mm_reg
    sla_voltage_out    : OUT t_mem_miso;  -- actual ranges defined by c_mm_reg

    -- MM registers
    --sens_err   : IN  STD_LOGIC := '0';
    --sens_data  : IN  t_slv_8_arr(0 TO g_sens_nof_result-1); -- FIXME should be OUT

    -- Max temp output
    temp_high  : OUT STD_LOGIC_VECTOR(6 DOWNTO 0)
  );
END unb2b_fpga_sens_reg;


ARCHITECTURE str OF unb2b_fpga_sens_reg IS

  --SIGNAL i_temp_high    : STD_LOGIC_VECTOR(6 DOWNTO 0);
                                  
BEGIN

  temp_high <= (others => '0'); --i_temp_high;

  u_fpga_sense: ENTITY fpga_sense_lib.fpga_sense
  GENERIC MAP (
    g_technology => g_technology,
    g_sim        => g_sim
  )
  PORT MAP (
    mm_clk      => mm_clk,
    mm_rst      => mm_rst,

    start_sense => start,

    reg_temp_mosi    => sla_temp_in,
    reg_temp_miso    => sla_temp_out,

    reg_voltage_store_mosi    => sla_voltage_in,
    reg_voltage_store_miso    => sla_voltage_out
  );

END str;
