-------------------------------------------------------------------------------
--
-- Copyright (C) 2012
-- ASTRON (Netherlands Institute for Radio Astronomy) <http://www.astron.nl/>
-- JIVE (Joint Institute for VLBI in Europe) <http://www.jive.nl/>
-- P.O.Box 2, 7990 AA Dwingeloo, The Netherlands
--
-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.
--
-------------------------------------------------------------------------------


-- Purpose: Simulate phase behaviour of PLL in normal mode
-- Description:
-- Usage:
-- > as 3
-- > run -all

LIBRARY IEEE, common_lib;
USE IEEE.STD_LOGIC_1164.ALL;
USE common_lib.common_pkg.ALL;


ENTITY tb_unb2b_board_clk200_pll IS
END tb_unb2b_board_clk200_pll;


ARCHITECTURE tb OF tb_unb2b_board_clk200_pll IS

  CONSTANT c_ext_clk_period    : TIME := 5 ns;               -- 200 MHz
  CONSTANT c_clk_vec_w         : NATURAL := 6;
  CONSTANT c_clk_div           : NATURAL := 32;
  
  SIGNAL tb_end         : STD_LOGIC := '0';
  SIGNAL ext_clk        : STD_LOGIC := '0';
  SIGNAL ext_rst        : STD_LOGIC;
  
  SIGNAL st_clk200_0    : STD_LOGIC;
  SIGNAL st_rst200_0    : STD_LOGIC;
  
  SIGNAL st_clk200p0    : STD_LOGIC;
  SIGNAL st_rst200p0    : STD_LOGIC;
  
  SIGNAL st_clk200_45   : STD_LOGIC;
  SIGNAL st_rst200_45   : STD_LOGIC;
  
  SIGNAL st_clk200p45   : STD_LOGIC;
  SIGNAL st_rst200p45   : STD_LOGIC;
  
  SIGNAL st_clk400      : STD_LOGIC;
  SIGNAL st_rst400      : STD_LOGIC;
  
  SIGNAL dp_clk200      : STD_LOGIC;
  SIGNAL dp_rst200      : STD_LOGIC;
  
BEGIN

  tb_end <= '0', '1' AFTER c_ext_clk_period*5000;
  
  ext_clk <= NOT ext_clk OR tb_end AFTER c_ext_clk_period/2;
  ext_rst <= '1', '0' AFTER c_ext_clk_period*7;
  
  dut_0 : ENTITY work.unb2b_board_clk200_pll
  GENERIC MAP (
    g_clk200_phase_shift  => "0"
  )
  PORT MAP (
    arst       => ext_rst,
    clk200     => ext_clk,
    st_clk200  => st_clk200_0,
    st_rst200  => st_rst200_0,
    st_clk200p => st_clk200p0,
    st_rst200p => st_rst200p0,
    st_clk400  => st_clk400,
    st_rst400  => st_rst400
  );
  
  dut_45 : ENTITY work.unb2b_board_clk200_pll
  GENERIC MAP (
    g_clk200_phase_shift  => "625",
    g_clk200p_phase_shift => "625"
  )
  PORT MAP (
    arst       => ext_rst,
    clk200     => ext_clk,
    st_clk200  => st_clk200_45,
    st_rst200  => st_rst200_45,
    st_clk200p => st_clk200p45,
    st_rst200p => st_rst200p45,
    st_clk400  => OPEN,
    st_rst400  => OPEN
  );
  
  dut_p6 : ENTITY work.unb2b_board_clk200_pll
  GENERIC MAP (
    g_clk200_phase_shift  => "0"
  )
  PORT MAP (
    arst       => ext_rst,
    clk200     => ext_clk,
    st_clk200  => dp_clk200,
    st_rst200  => dp_rst200
  );
  
END tb;
